@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.10';
+our $VERSION='0.11';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.10
+=head1 VERSION 0.11
 
 =cut
 
@@ -108,7 +108,7 @@ with 'Vote::Count::Approval',
   'Vote::Count::Floor',
   'Vote::Count::IRV',
   'Vote::Count::Log',
-  'Vote::Count::Range',  
+  'Vote::Count::Range',
   'Vote::Count::TieBreaker',
   'Vote::Count::TopCount',
   ;
@@ -118,11 +118,13 @@ sub VotesCast ( $self ) {
 }
 
 sub BallotSetType ( $self ) {
-  if( $self->BallotSet()->{'options'}{'rcv'} ) {
-    return 'rcv'
-  } elsif ( $self->BallotSet()->{'options'}{'range'} ) {
-    return 'range'
-  } else {
+  if ( $self->BallotSet()->{'options'}{'rcv'} ) {
+    return 'rcv';
+  }
+  elsif ( $self->BallotSet()->{'options'}{'range'} ) {
+    return 'range';
+  }
+  else {
     die "BallotSetType is undefined or unknown type.";
   }
 }
@@ -150,7 +152,7 @@ This is also extremely useful to researchers who may want to study multiple meth
   use feature qw /postderef signatures/;
 
   use Vote::Count;
-  use Vote::Count::ReadBallots 'read_ballots';
+  use Vote::Count::ReadBallots;
   use Vote::Count::Method::CondorcetDropping;
 
   # example uses biggerset1 from the distribution test data.
