@@ -13,13 +13,13 @@ with 'Vote::Count::TieBreaker';
 
 use Storable 3.15 'dclone';
 
-our $VERSION='0.10';
+our $VERSION='0.11';
 
 =head1 NAME
 
 Vote::Count::IRV
 
-=head1 VERSION 0.10
+=head1 VERSION 0.11
 
 =cut
 
@@ -48,9 +48,9 @@ sub _ResolveTie ( $self, $active, $tiebreaker, @choices ) {
   # use map to remove winner(s) from @choices.
   # warning about sort interpreted as function fixed
   my @low = sort map {
-      if   ( $high{$_} ) { }
-      else               { $_ }
-  } @choices ;
+    if   ( $high{$_} ) { }
+    else               { $_ }
+  } @choices;
   return @low;
 }
 
@@ -58,6 +58,11 @@ sub _irvrange ( $self, $active, $tiebreaker = undef ) {
   ...;
 }
 
+sub _checkmajority( ) { }
+
+#   if( $self->BallotSetType() eq 'range') {
+# return $self->_irvrange ( $active, $tiebreaker) }
+
 sub RunIRV ( $self, $active = undef, $tiebreaker = undef ) {
   # external $active should not be changed.
   if ( defined $active ) { $active = dclone $active }
@@ -71,8 +76,6 @@ sub RunIRV ( $self, $active = undef, $tiebreaker = undef ) {
       $tiebreaker = 'all';
     }
   }
-  if( $self->BallotSetType() eq 'range') {
-    return $self->_irvrange ( $active, $tiebreaker) }
   my $roundctr = 0;
   my $maxround = scalar( keys %{$active} );
   $self->logt( "Instant Runoff Voting",
